@@ -1,33 +1,10 @@
-/*
- * Copyright (c) 2004-2017, Doug Harple.  All rights reserved.
+/**
+ * This file is part of the Detox package.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are
- * met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * 3. Neither the name of author nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * Copyright (c) Doug Harple <detox.dharple@gmail.com>
  *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
  */
 
 #include "config.h"
@@ -166,7 +143,7 @@ unsigned char *clean_iso8859_1(unsigned char *s, void *opts)
  *     &  into  _and_
  *
  *   Replace with _:
- *     ` ! @ $ * \ | : ; " ' < ? /
+ *     ` ! @ $ * \ | : ; " ' < ? / '\n' '\r' '\t'
  *
  *   Replace with -:
  *     ( ) [ ] { }
@@ -233,6 +210,9 @@ unsigned char *clean_safe_basic(unsigned char *s, void *opts)
 			case '>':
 			case '?':
 			case '/':
+			case '\n':
+			case '\r':
+			case '\t':
 				*output_walk++ = '_';
 				break;
 
